Rdocumentation
powered by
Learn R Programming
GSM (version 1.3.2)
allcurves.q: Utility Function
Description
Utility function for plotting a Gamma Shape Mixture Model density.
Usage
allcurves.q(post, perc)
Arguments
post
matrix containing of a mixture's density posterior draws.
perc
percentile, a value that satisfies 0 < perc < 1.
Details
This is a utility function used to generate the credibility bands for a Gamma Shape Mixture density within
plot
.
See Also
plot-methods
.